==> pvops-0.1.8.tar.gz: pvops-0.1.8/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

import mock
MODULES = ['numpy', 'nltk', 'sklearn.pipeline', 'sklearn.model_selection',
           'scipy.sparse', 'pandas', 'scipy', 'sklearn.base',
           'gensim.models.doc2vec', 'nltk.tokenize', 'datefinder',
           'text_remove_nondate_nums', 'text_remove_numbers_stopwords',
           'get_dates', 'gensim.models', 'sklearn.svm', 'sklearn.tree',
           'sklearn.neural_network', 'sklearn.linear_model',
           'sklearn.ensemble', "sklearn.cluster", "networkx", "matplotlib",
           "matplotlib.pyplot", "gensim.models.doc2vec",
           "sklearn.feature_extraction.text", "nltk.tokenize",
           "plotly.graph_objects", "scipy.signal", 'matplotlib.colors',
           'seaborn', 'matplotlib.ticker', 'scipy.signal.find_peaks',
           'pvlib', 'pvanalytics', 'timezonefinder', 'sklearn', "pyDOE",
           "sklearn.metrics", "scipy.interpolate", "keras", "keras.layers",
           "sklearn.utils", "sklearn.preprocessing", "keras.models",
           "keras.utils"]

for module in MODULES:
    sys.modules[module] = mock.Mock()

sys.path.insert(0, os.path.abspath("../pvops"))
sys.path.insert(0, os.path.abspath("../pvops/text2time"))
sys.path.insert(0, os.path.abspath("../pvops/text"))
sys.path.insert(0, os.path.abspath("../pvops/timeseries"))
sys.path.insert(0, os.path.abspath("../pvops/iv"))


# -- Project information -----------------------------------------------------

project = "pvops"
copyright = "2021, Thushara Gunda"
author = "Thushara Gunda"

# The full version, including alpha/beta/rc tags
release = "0.1"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ["sphinx.ext.autodoc",
              "nbsphinx",
              "nbsphinx_link",
              "sphinx_copybutton"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

==> pvops-0.1.9.tar.gz: pvops-0.1.9/docs/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys


sys.path.insert(0, os.path.abspath("../pvops"))
sys.path.insert(0, os.path.abspath("../pvops/text2time"))
sys.path.insert(0, os.path.abspath("../pvops/text"))
sys.path.insert(0, os.path.abspath("../pvops/timeseries"))
sys.path.insert(0, os.path.abspath("../pvops/timeseries/models"))
sys.path.insert(0, os.path.abspath("../pvops/iv"))
sys.path.insert(0, os.path.abspath("../pvops/iv/models"))

# -- Project information -----------------------------------------------------

project = "pvops"
copyright = "2021, Thushara Gunda"
author = "Thushara Gunda"

# The full version, including alpha/beta/rc tags
release = "0.1"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    # pull in documentation from docstrings in a semi-automatic way.
    "nbsphinx",
    # nbsphinx is a Sphinx extension that provides a source parser
    # for *.ipynb files
    "nbsphinx_link",
    # A sphinx extension for including notebook files from outside
    # the sphinx source root.
    "sphinx_copybutton",
    # adds copy button to code blocks
    "sphinx.ext.coverage",
    # `make coverage` summarizes what has docstrings
    'sphinx.ext.doctest',
    # allows for testing of code snippets
    'sphinx.ext.viewcode',
    # add links to highlighted source code
    'sphinx.ext.napoleon'
    # add parsing for google/numpy style docs
]


coverage_show_missing_items = True
napoleon_numpy_docstring = True  # use numpy style
napoleon_google_docstring = False  # not google style
napoleon_use_rtype = False  # option for return section formatting
numpydoc_show_class_members = True
numpydoc_show_inherited_class_members = False
numpydoc_class_members_toctree = False
napoleon_use_ivar = True  # option for attribute section formatting
napoleon_use_param = False  # option for parameter section formatting

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]
html_style = 'css/my_style.css'
